@@ -1,10 +1,10 @@
 // Copyright (c) 2025 Manuel Schneider
 #pragma once
 #include <albert/extensionplugin.h>
-#include <albert/triggerqueryhandler.h>
+#include <albert/generatorqueryhandler.h>
 
-class Plugin : public albert::util::ExtensionPlugin,
-               public albert::TriggerQueryHandler
+class Plugin : public albert::ExtensionPlugin,
+               public albert::GeneratorQueryHandler
 {
     ALBERT_PLUGIN
 public:
@@ -14,6 +14,5 @@ public:
 
     bool allowTriggerRemap() const override;
     QString synopsis(const QString &) const override;
-    void handleTriggerQuery(albert::Query &) override;
-
+    albert::ItemGenerator items(albert::QueryContext &) override;
 };
