@@ -1,13 +1,13 @@
 // Copyright (c) 2025-2025 Manuel Schneider
 
 #pragma once
+#include "api.h"
 #include "handlers.h"
-#include "spotify.h"
 #include <albert/extensionplugin.h>
 #include <albert/urlhandler.h>
 #include <vector>
 
-class Plugin final : public albert::util::ExtensionPlugin,
+class Plugin final : public albert::ExtensionPlugin,
                      private albert::UrlHandler
 {
     ALBERT_PLUGIN
@@ -16,6 +16,7 @@ public:
 
     Plugin();
     ~Plugin() override;
+    void initialize() override;
 
     QWidget* buildConfigWidget() override;
     std::vector<albert::Extension*> extensions() override;
@@ -23,7 +24,9 @@ public:
 
 private:
 
-    spotify::RestApi api;
+    void writeSecrets();
+
+    RestApi api;
 
     TrackSearchHandler track_search_handler;
     ArtistSearchHandler artist_search_hanlder;
