@@ -1,6 +1,6 @@
 // Copyright (c) 2024-2024 Manuel Schneider
 
-#include "albert.h"
+#include "albert/app.h"
 #include "pluginssortproxymodel.h"
 #include <QSettings>
 using namespace albert;
@@ -10,7 +10,7 @@ const bool  DEF_SORT_MODE = true;
 
 PluginsSortProxyModel::PluginsSortProxyModel(QObject *parent) : QSortFilterProxyModel(parent)
 {
-    show_enabled_first_ = settings()->value(CFG_SORT_MODE, DEF_SORT_MODE).toBool();
+    show_enabled_first_ = App::settings()->value(CFG_SORT_MODE, DEF_SORT_MODE).toBool();
 }
 
 bool PluginsSortProxyModel::lessThan(const QModelIndex &left, const QModelIndex &right) const
@@ -32,7 +32,7 @@ void PluginsSortProxyModel::setShowEnabledFirst(bool value)
     if (value != show_enabled_first_)
     {
         show_enabled_first_ = value;
-        settings()->setValue(CFG_SORT_MODE, show_enabled_first_);
+        App::settings()->setValue(CFG_SORT_MODE, show_enabled_first_);
         invalidate();
         sort(0);
     }
